%define upstream_name    Domain-PublicSuffix
%define upstream_version 0.21

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Default PublicSuffix data file
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Domain/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Class::Accessor::Fast)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(Net::IDN::Encode) >= 2.401.0
BuildRequires: perl(Test::More) >= 0.880.0
BuildArch:  noarch

%description
This module utilizes the "effective_tld_names.dat" provided by Mozilla as a
way to effectively reduce a fully qualified domain name down to the
absolute root. The Mozilla PublicSuffix file is an open source, fully
documented format that shows absolute root TLDs, primarily for Mozilla's
browser products to be able to determine how far a cookie's security
boundaries go.

This module will attempt to search etc directories in
/usr/share/publicsuffix, /usr, /usr/local, and /opt/local for the
effective_tld_names.dat file. If a file is not found, a default file is
loaded from Domain::PublicSuffix::Default, which is current at the time of
the module's release. You can override the data file path by giving the
new() method a 'data_file' argument.

When creating a new PublicSuffix object, the module will load the data file
as specified, and use the internal structure to parse each domain sent to
the get_root_domain method. To re-parse the file, you must destroy and
create a new object, or execute the _parse_data_file method directly,
though that is not recommended.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes LICENSE META.yml MYMETA.yml README
%{_mandir}/man3/*
%perl_vendorlib/*
/usr/bin/get_root_domain
%{_mandir}/man1/get_root_domain.1*

%changelog
* Tue Jul 01 2025 umeabot <umeabot> 0.210.0-2.mga10
+ Revision: 2234413
- Mageia 10 Mass Rebuild

* Fri Jan 24 2025 tv <tv> 0.210.0-1.mga10
+ Revision: 2141570
- update to 0.21

* Wed Aug 30 2023 tv <tv> 0.200.0-1.mga10
+ Revision: 1981081
- update to 0.20

* Mon Mar 21 2022 umeabot <umeabot> 0.190.0-2.mga9
+ Revision: 1814033
- Mageia 9 Mass Rebuild

* Thu Feb 25 2021 tv <tv> 0.190.0-1.mga9
+ Revision: 1691273
- update to 0.19

* Tue Apr 14 2020 tv <tv> 0.170.0-1.mga8
+ Revision: 1567218
- update to 0.17

* Sun Feb 16 2020 umeabot <umeabot> 0.160.0-2.mga8
+ Revision: 1536555
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Sat Oct 19 2019 tv <tv> 0.160.0-1.mga8
+ Revision: 1454586
- update to 0.16

* Sun Jun 30 2019 tv <tv> 0.150.0-1.mga8
+ Revision: 1416421
- update to 0.15

* Wed Sep 19 2018 umeabot <umeabot> 0.100.0-4.mga7
+ Revision: 1267834
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 0.100.0-3.mga6
+ Revision: 1026848
- Rebuild for perl 5.22.2

* Thu Feb 18 2016 umeabot <umeabot> 0.100.0-2.mga6
+ Revision: 966825
- Mageia 6 Mass Rebuild

* Sun Jun 28 2015 sander85 <sander85> 0.100.0-1.mga6
+ Revision: 846933
- update to 0.10

* Sun Oct 19 2014 umeabot <umeabot> 0.90.0-5.mga5
+ Revision: 789525
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.90.0-4.mga5
+ Revision: 751024
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.90.0-3.mga5
+ Revision: 684607
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.90.0-2.mga4
+ Revision: 526319
- Mageia 4 Mass Rebuild

* Mon Jun 03 2013 jquelin <jquelin> 0.90.0-1.mga4
+ Revision: 436622
- update to 0.09

* Sun Jan 13 2013 umeabot <umeabot> 0.70.0-2.mga3
+ Revision: 366738
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Oct 21 2012 jquelin <jquelin> 0.70.0-1.mga3
+ Revision: 308742
- imported package perl-Domain-PublicSuffix


* Sun Oct 21 2012 cpan2dist 0.07-1mga
- initial mageia release, generated with cpan2dist
